I found now the functions are getting bigger and bigger, usually one feature cannot cover all the function required. so we may split it into feature 001-A, B, C...

So why not let's introduce the concept of Epic.

when we using Requirement Gathering skill to do Requirement Gathering, we no longer split or create feature level content, and we can convert existing feature level content to Epic level.

then when we doing feature breakdown using feature breakdown skill, we try to keep existing logic but adding epic to feature mapping support.

so the logic would be

Requirement Gathering -> create epics, all the AC and requirements should at Epic level, -> feature breakdown -> breakdown the Epic needs into features.

Epic naming convension can be Epic-{nnn}, Feature naming convension should be Feature-{nnn}-{A|B|C...}, the nnn here within feature should follow epic's number